[−][src]Crate automatic
Automatic
automatic run command throw user defined scripts
Commands collect to run items in run list.
Modules
| promiscuous_list | Promiscous run items, no output but aborts if one fail |
| run | Run trait for unificate run any items |
| runitem | Collect run parameters and run command |
| runner | Run command item with OS defined wrappers |
| script | Yaml script parser and run items list collector |
| silent_list | Silent run items, no output but aborts if one fail start or fail exit |